/*
    This file is part of "now", a simple calendar tool
    Copyright (C) 2012-2015  Laurent Poirrier

    "now" is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include "memory.h"
#include "bio.h"
#include "dateproc.h"
#include "utf8.h"
#include "terminal.h"
#include "screen.h"
#include "event.h"
#include "ical.h"
#include "ui.h"
#include "textedit.h"
#include "main.h"

// *************************************************************************
// 
// *************************************************************************
#define DEBUG(s...)	fprintf(stderr, s)
#define PRINT(s...)	fprintf(stdout, s)


// *************************************************************************
// 
// *************************************************************************
#define HELP_MSG	\
"Usage: now [-c file.ics]\n" \
"\n" \
"Options:\n" \
"  -c, --calendar       Specify iCal file\n" \
"                       (default: $HOME/.local/share/now/calendar.ics)\n" \
"  -h, --help           Show this help and exit\n" \
"  -v, --version        Show version and exit\n" \
"\n"

#define VERSION_MSG	\
"now v1.2 Copyright (C) 2012-2015  Laurent Poirrier\n" \
"\n" \
"This program comes with ABSOLUTELY NO WARRANTY.\n" \
"This is free software, and you are welcome to redistribute it\n" \
"under certain conditions; see COPYING for details.\n" \
"\n"

// *************************************************************************
// 
// *************************************************************************
/* static int test_daytime(char *cal_path)
{
	dt_time r;
	time_t t;
	
	r.year = 2000 + 12;
	r.mon = 3;
	r.mday = 23;
	r.hour = 12;
	r.min = 0;
	r.sec = 0;
	
	t = dt_nextday(dt_mktime(&r), 1);
	
	dt_localtime(t, &r);
	
	printf("Gives: %4d-%02d-%02d, %02d:%02d:%02d\n",
		r.year, r.mon, r.mday, r.hour, r.min, r.sec);
	
	return(0);
} // */

// *************************************************************************
// 
// *************************************************************************
int main(int argc, char **argv)
{
	int r, t;
	char *home;
	char *cal_path, *def_path;
	
	def_path = NULL;
	cal_path = NULL;
	
	for (t = 1; t < argc; t++) {
		if ((!strcmp(argv[t], "-c"))
		||  (!strcmp(argv[t], "--calendar"))) {
			if (t + 1 >= argc) {
				DEBUG("-c: calendar path expected\n");
				return(-1);
			}
			cal_path = argv[++t];
		} else if ((!strcmp(argv[t], "-v"))
		||  (!strcmp(argv[t], "--version"))) {
			PRINT("%s", VERSION_MSG);
			return(0);
		} else if ((!strcmp(argv[t], "-h"))
		||  (!strcmp(argv[t], "--help"))) {
			PRINT("%s", HELP_MSG);
			return(0);
		} else {
			DEBUG("%s", HELP_MSG);
			return(-1);
		}
	}
	
	if (!cal_path) {
		home = getenv("HOME");
		if (!home) {
			DEBUG("getenv(\"HOME\"): %s", strerror(errno));
			return(1);
		}
		
		def_path = xprintf("%s/.local/share/now/calendar.ics", home);
		cal_path = def_path;
	}
	
	r = ui_run(cal_path);
	
	if (def_path)
		xfree(def_path);
	
	return(r);
}


	/*
	// test iCal I/O
	event_list l;
	
	evlist_init(&l);
	evlist_ical_load(&l, "output.ics");
	evlist_ical_save(&l, "output2.ics");
	return(0);*/

/*
int main(int argc, char **argv)
{
	// test keyboard input
	term tty;
	int t, i;
	term_keypress k;
	
	term_open(&tty);
	
	for (t = 0; t < 10; t++) {
		term_getkey(&tty, &k);
		for (i = 0; i < k.n; i++)
			printf(" %d {%c},", k.k[i], k.k[i]);
		printf("\n");
	}
	
	term_close(&tty);
	return(0);
} // */
	
	/*
	// test UTF-8
	char *s = "ȮéàËabcd";
	
	printf("%s: %zd - %zd\n", s, strlen(s), utf8_strlen(s));
	return(0);*/

