/*
    This file is part of "now", a simple calendar tool
    Copyright (C) 2012-2015  Laurent Poirrier

    "now" is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "utf8.h"

size_t utf8_bytes(char *s0)
{
	unsigned char *s = (unsigned char *)s0;
	size_t b;
	
	for (b = 0; b < 4; b++) {
		if (!s[b]) {
			return(b);
		} else if ((s[b] & 0xc0) != 0xc0) {
			return(b + 1);
		}
	}
	
	return(b);
}

size_t utf8_full(char *s0, size_t bmax)
{
	unsigned char *s = (unsigned char *)s0;
	size_t b;
	
	for (b = 0; b < bmax; b++) {
		if ((s[b] & 0xc0) != 0xc0) {
			return(b + 1);
		}
	}
	
	if (bmax >= 4)
		return(4);
	
	return(bmax + 1);
}

utf8_code utf8_encode(char *s0)
{
	unsigned char *s;
	size_t b;
	utf8_code c;
	
	s = (unsigned char *)s0;
	b = utf8_bytes(s0);
	c = s[0];
	if (b >= 2)
		c |= s[1] << 8;
	if (b >= 3)
		c |= s[2] << 16;
	if (b >= 4)
		c |= s[3] << 24;
	
	return(c);
}


size_t utf8_strlen(char *s)
{
	size_t b;
	
	b = 0;
	while (*s) {
		s += utf8_bytes(s);
		b++;
	}
	
	return(b);
}

size_t utf8_extract(utf8_code *dst, char *s, size_t lmax)
{
	size_t b;
	
	b = 0;
	while ((*s) && (b < lmax)) {
		dst[b++] = utf8_encode(s);
		s += utf8_bytes(s);
	}
	
	return(b);
}

size_t utf8_render(char *dst, utf8_code *src, size_t l)
{
	size_t o, b;
	utf8_code c;
	
	b = 0;
	for (o = 0; o < l; o++) {
		c = src[o];
		dst[b++] = c;
		if (c >> 8)
			dst[b++] = c >> 8;
		if (c >> 16)
			dst[b++] = c >> 16;
		if (c >> 24)
			dst[b++] = c >> 24;
	}
	
	return(b);
}


